dispMUA.arDispMUAAllocation["k"] =
{
  "kayako supportsuite" : [ "kayako.png" ] ,
  "kerio mailserver" : [ "kerio.png" ] ,
  "kochmeister.com" : [ "kochmeister.png" , "http://www.kochmeister.com/" ] ,
  "kayako esupport" : [ "kayako.png" ] ,
  "kaufman pravda" : [ "kaufman_pravda.png" , "http://www.kaufmansoft.com/" ] ,
  "karen's mailer" : [ "karensmailer.png" ] ,
  "kontur-extern" : [ "kontur-extern.png" , "http://www.kontur-extern.ru/" ] ,
  "kienis mailer" : [ "kienis_mailer.png" ] ,
  "kerio outlook" : [ "kerio.png" ] ,
  "kana response" : [ "kana_response.png" ] ,
  "kajomimail" : [ "kajomi.png" ] ,
  "kurinnaxx" : [ "kurinnaxx.png" ] ,
  "kopiemail" : [ "kopiemail.png" ] ,
  "koma-mail" : [ "koma_mail.png" , "http://www.koma-code.de/" ] ,
  "kolbaskin" : [ "kolbaskin.png" , "http://habrahabr.ru/" ] ,
  "knallhart" : [ "knallhart.png" , "http://www.knallhart.de/" ] ,
  "kaspersky" : [ "kaspersky.png" ] ,
  "katamail" : [ "katamail.png" ] ,
  "koomail" : [ "koomail.png" , "http://www.koomail.com/" ] ,
  "k-mail" : [ "k-mail.png" , "http://www.kcsoftwares.com/" ] ,
  "knode" : [ "knode.png" ] ,
  "knews" : [ "knews.png" ] ,
  "kmail" : [ "kmail.png" , "http://kontact.kde.org/kmail/" ] ,
  "ken!" : [ "ken.png" , "http://www.avm.de/" ] ,
  "kana" : [ "kana.png" ] ,
}
